|Docs| |PyPI| 


.. |Docs| image:: https://readthedocs.com/projects/icb-scanpy/badge/?version=latest
   :target: https://episcanpy.readthedocs.io/en/latest/
.. |PyPI| image:: https://img.shields.io/pypi/v/episcanpy.svg
    :target: https://pypi.org/project/episcanpy



EpiScanpy – Epigenomics single cell analysis in python
======================================================

**EpiScanpy** is a toolkit to analyse single-cell open chromatin (scATAC-seq) and single-cell DNA methylation (for example scBS-seq) data. **EpiScanpy** is the epigenomic extension of the very popular scRNA-seq analysis tool **Scanpy** (`Genome Biology <https://doi.org/10.1186/s13059-017-1382-0>`__, 2018) [Wolf18]. For more information, read scanpy `documentation <https://scanpy.readthedocs.io>`__. 

The documentation for epiScanpy is available `here <https://episcanpy.readthedocs.io/en/latest/>`__. If epiScanpy is useful to your research, consider citing `epiScanpy <https://www.biorxiv.org/content/10.1101/648097v1>`__.
